get_app_details

Function get_app_details 

pub fn get_app_details() -> &'static AppDetails
Gets the details for this application.

This includes basic information like the application name and semantic version, and information that might otherwise fall under the general umbrella of “build metadata.”

If the application hasn’t registered its details through set_app_details, the name and version fields report "unknown" and 0.0.0 respectively. Build metadata is always populated, since it’s captured at compile time.