Version

Struct Version 

pub struct Version { /* private fields */ }
A simple representation of a semantic version.

Implementations

Source

impl Version

pub fn raw(&self) -> &'static str

Returns the raw version string.

pub fn major(&self) -> u32

Returns the major version number.

If the major version number isn’t present in the version string, this will return 0.

pub fn minor(&self) -> u32

Returns the minor version number.

If the minor version number isn’t present in the version string, this will return 0.

pub fn patch(&self) -> u32

Returns the patch version number.

If the patch version number isn’t present in the version string, this will return 0.